searchData={"items":[{"type":"module","title":"FLAMESlurmBackend","doc":"Slurm Backend implementation.","ref":"FLAMESlurmBackend.html"},{"type":"module","title":"Usage - FLAMESlurmBackend","doc":"Configure the flame backend in our configuration or application setup:\n\nwrite a jobscript\n```\n#!/bin/bash\n#SBATCH -o flame.%j.out\n#SBATCH --nodes=1\n#SBATCH --ntasks-per-node=1\n#SBATCH --time=01:00:00\n#SBATCH --mem=20G\n\nexport SLURM_FLAME_HOST=$(ip -f inet addr show ib0 | awk '/inet/ {print $2}' | cut -d/ -f1)\n```\n\nsetting a Partition with GPU instances and 1 GPU per job\n```\n#SBATCH --partition=gpu\n#SBATCH --gpus-per-node=1\n```\n\n\n```\n# application.ex\nchildren = [\n  {FLAME.Pool,\n    name: MyApp.SamplePool,\n    code_sync: [\n   start_apps: true,\n   sync_beams: Kino.beam_paths(),\n   compress: false,\n   extract_dir: {\n     FLAMESlurmBackend.SlurmClient,\n     :path_job_id,\n     [Path.absname(\"extract_dir\")<>\"/\"]\n   }\n ],\n min: 0,\n max: 1,\n max_concurrency: 1,\n idle_shutdown_after: :timer.minutes(10),\n timeout: :infinity,\n boot_timeout: 360000,\n track_resources: true,\n    backend: {\n      FLAMESlurmBackend,\n      slurm_job:  \n    }\n    }\n]\n```\n\nwhen running inside a Livebook:\n\nStart the Livebook with a matching Host part of the Erlang long name:\nUsing LIVEBOOK_IP=0.0.0.0 is helpful if you create a portforwarding from the login Host of the Cluster.\n\n```\n#!/bin/bash\nexport SLURM_FLAME_HOST=$(ip -f inet addr show ib0 | awk '/inet/ {print $2}' | cut -d/ -f1)\nepmd -daemon\nLIVEBOOK_IP=0.0.0.0 livebook server --name livebook@$SLURM_FLAME_HOST\n```\n\n```\nKino.start_child(\n  {FLAME.Pool,\n   name: :runner,\n   code_sync: [start_apps: true, sync_beams: Kino.beam_paths(), compress: false],\n   min: 0,\n   max: 1,\n   max_concurrency: 10,\n   idle_shutdown_after: :timer.minutes(1),\n   timeout: :infinity,\n   track_resources: true,\n   backend: {FLAMESlurmBackend, slurm_job:  }}\n)\n```","ref":"FLAMESlurmBackend.html#module-usage"},{"type":"extras","title":"FLAMESlurmBackend","doc":"# FLAMESlurmBackend\n\nThe Flame Slurm Backend allows to use FLAME on SLURM HPC Clusters.","ref":"readme.html"},{"type":"extras","title":"Installation - FLAMESlurmBackend","doc":"```elixir\ndef deps do\n  [\n    {:flame_slurm_backend,github: \"marcnnn/flame_slurm_backend\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - FLAMESlurmBackend","doc":"Configure the flame backend in our configuration or application setup:\n\n```elixir\n  # application.ex\n  children = [\n    {FLAME.Pool,\n    name: MyApp.SamplePool,\n    code_sync: [\n     start_apps: true,\n     sync_beams: Kino.beam_paths(),\n     compress: false,\n     extract_dir: {\n       FLAMESlurmBackend.SlurmClient,\n       :path_job_id,\n       [Path.absname(\"extract_dir\")<>\"/\"]\n     } \n   ],\n   min: 0,\n   max: 1,\n   max_concurrency: 1,\n   idle_shutdown_after: :timer.minutes(10),\n   timeout: :infinity,\n   boot_timeout: 360000,\n   track_resources: true,\n    slurm_job: \"\"\"\n      #!/bin/bash\n      #SBATCH -o flame.%j.out\n      #SBATCH --nodes=1\n      #SBATCH --ntasks-per-node=1\n      #SBATCH --time=01:00:00\n      #SBATCH --mem=20G\n\n      export SLURM_FLAME_HOST=$(ip -f inet addr show ib0 | awk '/inet/ {print $2}' | cut -d/ -f1)\n      \"\"\"\n    }\n  ]\n```\n\nThe `slurm_job` defines the Slurm job that will run on each spawned machine.\n\nThe `SLURM_FLAME_HOST` environment variable is also explicitly customize to the infiniband interface, which will be used by the Erlang VM Distribution layer for low latency and high bandwidth communication:\n\n```bash\nexport SLURM_FLAME_HOST=$(ip -f inet addr show ib0 | awk '/inet/ {print $2}' | cut -d/ -f1)\n```\n\nYou will need to start the parent Erlang VM (the one that configures FLAME) with the same configuration. If you are using Livebook, here is a script that starts on a CUDA 12.5 with CUDNN in `$HOME`:\n\n```bash\n#!/bin/bash\nexport CUDA=/usr/local/cuda-12.5/\nexport CUDNN=$HOME/cudnn-linux-x86_64-9.5.0.50_cuda12-archive/\nexport PATH=$PATH:$CUDA/bin\nexport CPATH=$CPATH:$CUDNN/include:$CUDA/include\nexport LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$CUDNN/lib\nexport MIX_INSTALL_DIR=$WORK/mix-cache\n\nexport SLURM_FLAME_HOST=$(ip -f inet addr show ib0 | awk '/inet/ {print $2}' | cut -d/ -f1)\n\nepmd -daemon\nLIVEBOOK_IP=0.0.0.0 LIVEBOOK_PASSWORD=***** MIX_ENV=prod livebook server --name livebook@$SLURM_FLAME_HOST\n```","ref":"readme.html#usage"},{"type":"extras","title":"Prerequisites - FLAMESlurmBackend","doc":"The Flame Parent and the Slurm cluster need to be able to connect via Erlang PRC.","ref":"readme.html#prerequisites"},{"type":"extras","title":"Env Variables - FLAMESlurmBackend","doc":"In order for the runners to be able to join the cluster, you need to configure\na few environment variables on your pod/deployment:","ref":"readme.html#env-variables"},{"type":"extras","title":"How it works - FLAMESlurmBackend","doc":"The FLAME Slurm backend needs to run inside the cluster.\nThe backend then sends the a command to queue a job to the cluster.\nThis Job will than be scheduled if ressoucces are avaiable.\nIf it not scheduled within the timeout the job is canceled to not block ressourcess that are no longer needed.\nTo be able to run the runner with the correct enviorment cluster specific bash file needs to be created.\n\n# Cleanup\n\nSlurm is configured to send a SIGTERM signal to FLAME 30 seconds before it terminates the Job, so it starts performing any cleaning up of Flame temporary Files.\n\nIf your Slurm cluster is not configured to delete the tmp folder you can use OTP supervisors and delete artifacts that you create on termination.\n\nThis implementation in Flame is a good reference how to do that:\nhttps://github.com/phoenixframework/flame/commit/e64ad84b695a7569a351b7e5717c27db97f2451c\n\n# Long running Jobs\n\nIf your job time is limited, Slurm will kill the Job while it is running. There are no mechanisms at the moment to not use the runner if time is about to run out. This would be a well appreciated contribution! Be aware that you might lose data because of this.","ref":"readme.html#how-it-works"},{"type":"extras","title":"Troubleshooting - FLAMESlurmBackend","doc":"","ref":"readme.html#troubleshooting"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Changelog","doc":"<!-- Add your changelog entry to the relevant subsection -->\n\n<!--","ref":"changelog.html#unreleased"},{"type":"extras","title":"Added | Changed | Deprecated | Removed | Fixed | Security --> - Changelog","doc":"<!--------------------- Don't add new entries after this line --------------------->\n\n\n## [0.1.0] - 2024-11-02\n\n- Very early stage implementation of a Slurm backend.","ref":"changelog.html#added-changed-deprecated-removed-fixed-security"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}